use strict;
use warnings;

use vars qw($VERSION);

$VERSION = 0.02;

=head1 NAME

Persistence::Manual - Index of the Manual

=head1 DESCRIPTION

This is the L<Persisistence::Entity> users manual
for the persisitence API between database entities and perl classes.

=head1 SECTIONS

=head2 L<Persistence::Manual::Introduction>

Beginner guide to using persistence API.

=head2 L<Persistence::Manual::EntityManager>

Persistence actions.

=head2 L<Persistence::Manual::Relationship>

Object relationships

=head2 L<Persistence::Manual::LOB>

Large objects attributes persisitence.

=cut
